summaryrefslogtreecommitdiffstats
path: root/source/BlockEntities/HopperEntity.h
diff options
context:
space:
mode:
authormadmaxoft <github@xoft.cz>2013-08-11 14:57:07 +0200
committermadmaxoft <github@xoft.cz>2013-08-11 14:57:07 +0200
commitdd60f55bccd603650906d5025f689a82d00b3718 (patch)
tree773db077844972b21488c448f88572ca691baa51 /source/BlockEntities/HopperEntity.h
parentAdded an AllowEmptyStacks param to cItemGrid::HowManyCanFit(). (diff)
downloadcuberite-dd60f55bccd603650906d5025f689a82d00b3718.tar
cuberite-dd60f55bccd603650906d5025f689a82d00b3718.tar.gz
cuberite-dd60f55bccd603650906d5025f689a82d00b3718.tar.bz2
cuberite-dd60f55bccd603650906d5025f689a82d00b3718.tar.lz
cuberite-dd60f55bccd603650906d5025f689a82d00b3718.tar.xz
cuberite-dd60f55bccd603650906d5025f689a82d00b3718.tar.zst
cuberite-dd60f55bccd603650906d5025f689a82d00b3718.zip
Diffstat (limited to 'source/BlockEntities/HopperEntity.h')
-rw-r--r--source/BlockEntities/HopperEntity.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/source/BlockEntities/HopperEntity.h b/source/BlockEntities/HopperEntity.h
index 8fc17b631..a49868660 100644
--- a/source/BlockEntities/HopperEntity.h
+++ b/source/BlockEntities/HopperEntity.h
@@ -78,11 +78,11 @@ protected:
/// Moves items from a furnace above the hopper into this hopper. Returns true if contents have changed.
bool MoveItemsFromFurnace(cChunk & a_Chunk);
- /// Moves items from the specified ItemGrid into this hopper. Returns true if contents have changed.
- bool MoveItemsFromGrid(cItemGrid & a_Grid);
+ /// Moves items from the specified a_Entity's Contents into this hopper. Returns true if contents have changed.
+ bool MoveItemsFromGrid(cBlockEntityWithItems & a_Entity);
/// Moves one piece from the specified itemstack into this hopper. Returns true if contents have changed. Doesn't change the itemstack.
- bool MoveItemsFromSlot(const cItem & a_ItemStack, bool a_AllowNewStacks);
+ bool MoveItemsFromSlot(cBlockEntityWithItems & a_Entity, int a_SrcSlotNum, bool a_AllowNewStacks);
/// Moves items to the chest at the specified coords. Returns true if contents have changed
bool MoveItemsToChest(cChunk & a_Chunk, int a_BlockX, int a_BlockY, int a_BlockZ);
@@ -91,10 +91,10 @@ protected:
bool MoveItemsToFurnace(cChunk & a_Chunk, int a_BlockX, int a_BlockY, int a_BlockZ, NIBBLETYPE a_HopperMeta);
/// Moves items to the specified ItemGrid. Returns true if contents have changed
- bool MoveItemsToGrid(cItemGrid & a_ItemGrid);
+ bool MoveItemsToGrid(cBlockEntityWithItems & a_Entity);
- /// Moves one piece to the specified ItemGrid's slot. Returns true if contents have changed.
- bool MoveItemsToSlot(cItemGrid & a_ItemGrid, int a_DestSlotNum);
+ /// Moves one piece to the specified entity's contents' slot. Returns true if contents have changed.
+ bool MoveItemsToSlot(cBlockEntityWithItems & a_Entity, int a_DstSlotNum);
} ;